/*
 * Created on Jun 25, 2004
 *
 * This file is licensed under the terms of the Artistic License as
 * described at http://www.opensource.org/licenses/artistic-license.php
 *
 * Use and/or redistribution under the terms of the GNU Lesser GPL
 * (http://www.opensource.org/licenses/lgpl-license.php) is also allowed.
 */
package com.blackperl.Perl;

import junit.framework.TestCase;
import java.util.HashMap;

/**
 * One-line class summary
 * 
 * Extended description
 * 
 * @author rjray
 * @version $Id: ChopTest.java,v 1.4 2004/07/20 08:31:17 rjray Exp $
 */
public class ChopTest extends TestCase
{

    /**
     * Constructor for ChopTest.
     * @param name
     */
    public ChopTest(String name)
    {
        super(name);
    }

    final public void testInstance()
    {
        // Call instance() twice. See if they match.
        Chop c1 = Chop.instance();
        Chop c2 = Chop.instance();
        
        assertEquals("Test two calls to instance() for equality", c1, c2);
    }

    /*
     * Test for char chop(StringBuffer)
     */
    final public void testChopStringBuffer()
    {
        StringBuffer buf = new StringBuffer("chopp");
        char retval = Chop.chop(buf);
        
        assertEquals("Test chop(StringBuffer) - return value", retval, 'p');
        assertEquals("Test chop(StringBuffer) - buffer value",
            buf.toString(), "chop");
        
        buf = new StringBuffer("");
        retval = Chop.chop(buf);
        
        assertEquals("Test chop(StringBuffer) - empty string return value",
            retval, '\0');
        assertEquals("Test chop(StringBuffer) - empty string buffer value",
            buf.toString(), "");
    }

    /*
     * Test for char chop(StringBuffer[])
     */
    final public void testChopStringBufferArray()
    {
        String[] strings = { "one", "two", "three", "four" };
        StringBuffer[] testBuffArr = new StringBuffer[strings.length];
        int i;
        char value;
        
        for (i = 0; i < strings.length; i++)
        {
            testBuffArr[i] = new StringBuffer(strings[i]);
            testBuffArr[i].append("+");
        }
        // Tweak the last one so that we know for certain we get the right
        // return value.
        i = strings.length - 1;
        testBuffArr[i].replace(testBuffArr[i].length() - 1,
            testBuffArr[i].length(), "-");
        
        value = Chop.chop(testBuffArr);
        assertEquals("Testing chop(StringBuffer[]) - return value",
            value, '-');
        for (i = 0; i < strings.length; i++)
        {
            assertEquals("Testing chop(StringBuffer[" + i + "]",
                strings[i], testBuffArr[i].toString());
        }
    }

    /*
     * Test for char chop(Map)
     */
    final public void testChopMap()
    {
        String[] strings = { "uno", "dos", "tres", "quatro" };
        StringBuffer[] testBufArr = new StringBuffer[strings.length];
        HashMap map = new HashMap();
        int i;
        char value;
        
        for (i = 0; i < strings.length; i++)
        {
            testBufArr[i] = new StringBuffer(strings[i]);
            testBufArr[i].append("+");
            map.put(new Integer(i), testBufArr[i]);
        }

        // I don't tweak the last buffer in this test because the iteration
        // order of the map isn't something I can arbitrarily predict.
        value = Chop.chop(map);
        assertEquals("Testing chop(Map) - return value",
            value, '+');
        // This is a cheat, since the Map had the same pointers. It's easier
        // than converting the Map's key back to int to use as an index.
        for (i = 0; i < strings.length; i++)
        {
            assertEquals("Testing chop(Map via StringBuffer[" + i + "])",
                strings[i], testBufArr[i].toString());
        }
    }

}
